<?php

namespace Mahasiswa\Mahasiswa\Http\Controllers;
use Litepie\Mahasiswa\Http\Requests\MahasiswaRequest;
use Litepie\Mahasiswa\Models\Mahasiswa;

trait MahasiswaWorkflow {
	
    /**
     * Workflow controller function for mahasiswa.
     *
     * @param Model   $mahasiswa
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MahasiswaRequest $request, Mahasiswa $mahasiswa, $step)
    {

        try {

            $mahasiswa->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('mahasiswa::mahasiswa.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/mahasiswa/mahasiswa/' . $mahasiswa->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/mahasiswa/mahasiswa/' . $mahasiswa->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for mahasiswa.
     *
     * @param Model   $mahasiswa
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Mahasiswa $mahasiswa, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $mahasiswa->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('mahasiswa::mahasiswa.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mahasiswa::admin.mahasiswa.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mahasiswa::admin.mahasiswa.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('mahasiswa::admin.mahasiswa.message', $data)->render();

        }

    }
}