<?php

namespace Mahasiswa\Mahasiswa\Policies;

use App\User;
use Mahasiswa\Mahasiswa\Models\Mahasiswa;

class MahasiswaPolicy
{

    /**
     * Determine if the given user can view the mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function view(User $user, Mahasiswa $mahasiswa)
    {
        if ($user->canDo('mahasiswa.mahasiswa.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mahasiswa->user_id;
    }

    /**
     * Determine if the given user can create a mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('mahasiswa.mahasiswa.create');
    }

    /**
     * Determine if the given user can update the given mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function update(User $user, Mahasiswa $mahasiswa)
    {
        if ($user->canDo('mahasiswa.mahasiswa.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mahasiswa->user_id;
    }

    /**
     * Determine if the given user can delete the given mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function destroy(User $user, Mahasiswa $mahasiswa)
    {
        if ($user->canDo('mahasiswa.mahasiswa.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $mahasiswa->user_id;
    }

    /**
     * Determine if the given user can verify the given mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function verify(User $user, Mahasiswa $mahasiswa)
    {
        if ($user->canDo('mahasiswa.mahasiswa.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('mahasiswa.mahasiswa.verify') 
        && $user->is('manager')
        && $mahasiswa->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mahasiswa.
     *
     * @param User $user
     * @param Mahasiswa $mahasiswa
     *
     * @return bool
     */
    public function approve(User $user, Mahasiswa $mahasiswa)
    {
        if ($user->canDo('mahasiswa.mahasiswa.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
