<?php

namespace Mahasiswa\Mahasiswa\Providers;

use Illuminate\Support\ServiceProvider;

class MahasiswaServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'mahasiswa');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'mahasiswa');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('mahasiswa', function ($app) {
            return $this->app->make('Mahasiswa\Mahasiswa\Mahasiswa');
        });

        // Bind Mahasiswa to repository
        $this->app->bind(
            \Mahasiswa\Mahasiswa\Interfaces\MahasiswaRepositoryInterface::class,
            \Mahasiswa\Mahasiswa\Repositories\Eloquent\MahasiswaRepository::class
        );

        $this->app->register(\Mahasiswa\Mahasiswa\Providers\AuthServiceProvider::class);
        $this->app->register(\Mahasiswa\Mahasiswa\Providers\EventServiceProvider::class);
        $this->app->register(\Mahasiswa\Mahasiswa\Providers\RouteServiceProvider::class);
        // $this->app->register(\Mahasiswa\Mahasiswa\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['mahasiswa'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('mahasiswa/mahasiswa.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/mahasiswa')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/mahasiswa')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
