<?php

namespace Mahasiswa\Mahasiswa\Workflow;

use Mahasiswa\Mahasiswa\Models\Mahasiswa;
use Validator;

class MahasiswaValidator
{

    /**
     * Determine if the given mahasiswa is valid for complete status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function complete(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given mahasiswa is valid for verify status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function verify(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given mahasiswa is valid for approve status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function approve(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given mahasiswa is valid for publish status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function publish(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given mahasiswa is valid for archive status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function archive(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given mahasiswa is valid for unpublish status.
     *
     * @param Mahasiswa $mahasiswa
     *
     * @return bool / Validator
     */
    public function unpublish(Mahasiswa $mahasiswa)
    {
        return Validator::make($mahasiswa->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
